shelltool

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package shelltool makes a sandboxed shell available as a tool to the LLM.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(allowNetwork bool) (*genai.GenOptionTools, error)

New return a shell tool that works on the current OS.

If allowNetwork is false, the script will not have network access.

  • On macOS, it runs /bin/zsh under sandbox-exec.
  • On Windows, it runs powershell under a restricted user token. It is currently disabled due to a crash in the Go runtime.
  • On other platforms, it runs bash under bubblewrap. bubblewrap must be installed separately.

Types

This section is empty.

Jump to