Documentation
¶
Overview ¶
Package shelltool makes a sandboxed shell available as a tool to the LLM.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
func New(allowNetwork bool) (*genai.GenOptionTools, error)
New return a shell tool that works on the current OS.
If allowNetwork is false, the script will not have network access.
- On macOS, it runs /bin/zsh under sandbox-exec.
- On Windows, it runs powershell under a restricted user token. It is currently disabled due to a crash in the Go runtime.
- On other platforms, it runs bash under bubblewrap. bubblewrap must be installed separately.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.